from avocado import Test
from avocado.utils import vmimage


class FedoraS390xVmimageTest(Test):
    """
    Example demonstrating VM image dependency with Fedora s390x architecture.
    The vmimage dependency runner will ensure the required VM image
    is downloaded and cached before the test execution begins.

    :avocado: dependency={"type": "vmimage", "provider": "fedora", "version": "41", "arch": "s390x"}
    """

    def test_fedora_s390x_image(self):
        """
        Simple example showing how to use vmimage.get to verify the image exists.
        """
        # Get the Fedora s390x image
        image = vmimage.get(name="fedora", version="41", arch="s390x")

        # Log the image path
        self.log.info("Fedora 41 s390x image path: %s", image.path)

        # Verify the image exists
        self.assertTrue(image.path, "Fedora 41 s390x image not found")


class FedoraX86VmimageTest(Test):
    """
    Example demonstrating VM image dependency with Fedora x86_64 architecture.

    :avocado: dependency={"type": "vmimage", "provider": "fedora", "version": "41", "arch": "x86_64"}
    """

    def test_fedora_x86_image(self):
        """
        Simple example showing how to use vmimage.get to verify the image exists.
        """
        # Get the Fedora x86_64 image
        image = vmimage.get(name="fedora", version="41", arch="x86_64")

        # Log the image path
        self.log.info("Fedora 41 x86_64 image path: %s", image.path)

        # Verify the image exists
        self.assertTrue(image.path, "Fedora 41 x86_64 image not found")


class CentOSVmimageTest(Test):
    """
    Example demonstrating VM image dependency with CentOS.

    :avocado: dependency={"type": "vmimage", "provider": "centos", "version": "8", "arch": "x86_64"}
    """

    def test_centos_image(self):
        """
        Simple example showing how to use vmimage.get to verify the image exists.
        """
        # Get the CentOS image
        image = vmimage.get(name="centos", version="8", arch="x86_64")

        # Log the image path
        self.log.info("CentOS 8 x86_64 image path: %s", image.path)

        # Verify the image exists
        self.assertTrue(image.path, "CentOS 8 x86_64 image not found")


class DebianVmimageTest(Test):
    """
    Example demonstrating VM image dependency with Debian.

    :avocado: dependency={"type": "vmimage", "provider": "debian", "version": "bullseye", "arch": "x86_64"}
    """

    def test_debian_image(self):
        """
        Simple example showing how to use vmimage.get to verify the image exists.
        """
        # Get the Debian image
        image = vmimage.get(name="debian", version="bullseye", arch="x86_64")

        # Log the image path
        self.log.info("Debian Bullseye (11) x86_64 image path: %s", image.path)

        # Verify the image exists
        self.assertTrue(image.path, "Debian Bullseye (11) x86_64 image not found")


class UbuntuVmimageTest(Test):
    """
    Example demonstrating VM image dependency with Ubuntu.

    :avocado: dependency={"type": "vmimage", "provider": "ubuntu", "version": "22.04", "arch": "x86_64"}
    """

    def test_ubuntu_image(self):
        """
        Simple example showing how to use vmimage.get to verify the image exists.
        """
        # Get the Ubuntu image
        image = vmimage.get(name="ubuntu", version="22.04", arch="x86_64")

        # Log the image path
        self.log.info("Ubuntu 22.04 x86_64 image path: %s", image.path)

        # Verify the image exists
        self.assertTrue(image.path, "Ubuntu 22.04 x86_64 image not found")
